"""Keypoints adapters."""

from .frame_keypoints import FrameKeypointsAdapter, FrameKeypointsDataAdapter
from .keypoint_annotation import KeypointAnnotationAdapter

__all__ = [
    "FrameKeypointsAdapter",
    "FrameKeypointsDataAdapter",
    "KeypointAnnotationAdapter",
]
